//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraArgs](index.md)/[options](options.md)

# options

[common]\
val [options](options.md): [HoraOptions](../-hora-options/index.md)
